==> django-secure-password-input-0.1.0.tar.gz: django-secure-password-input-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = fobj.readlines()

setup(
    name="django-secure-password-input",
    version="0.1.0",
    description="A simple django application provides function to encrypt password value with rsa public key before form submit and decrypt at the backend.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="zencore",
    author_email="dobetter@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django secure password input"],
    install_requires=requires,
    packages=find_packages(".", exclude=["django_secure_password_input_example", "django_secure_password_input_example.migrations", "django_secure_password_input_demo"]),
    py_modules=["django_secure_password_input"],
    zip_safe=False,
    include_package_data=True,
)

==> django-secure-password-input-0.1.1.tar.gz: django-secure-password-input-0.1.1/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-secure-password-input",
    version="0.1.1",
    description="A simple django application provides function to encrypt password value with rsa public key before form submit and decrypt at the backend.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/zencore-cn/zencore-issues",
    author="zencore",
    author_email="dobetter@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django secure password input"],
    install_requires=requires,
    packages=find_packages(".", exclude=["django_secure_password_input_example", "django_secure_password_input_example.migrations", "django_secure_password_input_demo"]),
    py_modules=["django_secure_password_input"],
    zip_safe=False,
    include_package_data=True,
)
